pub struct SectorRecordChunks {
pub source: Box<Record>,
pub parity: Box<Record>,
pub present: ShardsPresent<{ Record::NUM_CHUNKS }>,
}Expand description
Record chunks read from a sector.
Source and parity chunks are separate allocations so that a caller which only needs the source record can drop the parity one as soon as recovery is done. Contents of chunks that are not present are unspecified.
Fields
source: Box<Record>Source chunks
parity: Box<Record>Parity chunks
present: ShardsPresent<{ Record::NUM_CHUNKS }>Which chunks are present
Implementations